@@ -122,12 +122,12 @@ ROKEN_CPP_START
 #define asnprintf rk_asnprintf
 ROKEN_LIB_FUNCTION int ROKEN_LIB_CALL
     rk_asnprintf (char **, size_t, const char *, ...)
-     __attribute__ ((format (printf, 3, 4)));
+     __attribute__ ((__format__ (__printf__, 3, 4)));
 
 #define vasnprintf rk_vasnprintf
 ROKEN_LIB_FUNCTION int ROKEN_LIB_CALL
     vasnprintf (char **, size_t, const char *, va_list)
-     __attribute__((format (printf, 3, 0)));
+     __attribute__ ((__format__ (__printf__, 3, 0)));
 
 
 
